Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/SpectrumIM/spectrum2.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorhimselfv <me@boku.ru>2019-02-05 09:58:11 +0300
committervitalyster <vitalyster@gmail.com>2019-02-05 16:09:29 +0300
commitc4f4db0a41174332bad8286dc2693e16ed533a9b (patch)
tree60497056e26a8eff22f6d8d7505d5d05ec2b1ceb /include
parente455c9b77b0a5c7d1a3175a52b84f5539f12c836 (diff)
1. AuthRequestList for auth request, 2. Some comments
Diffstat (limited to 'include')
-rw-r--r--include/transport/NetworkPlugin.h17
1 files changed, 15 insertions, 2 deletions
diff --git a/include/transport/NetworkPlugin.h b/include/transport/NetworkPlugin.h
index cb38acfc..f8fd3770 100644
--- a/include/transport/NetworkPlugin.h
+++ b/include/transport/NetworkPlugin.h
@@ -75,7 +75,18 @@ class NetworkPlugin {
void sendRawXML(std::string &xml);
- /// Call this function when legacy network buddy changed.
+ /*
+ Spectrum backends follow Pidgin model where
+ - Buddies can only be mutual
+ - Adding a buddy sends a friend request and the buddy is not added until it's accepted.
+ - The only way to unfriend is to delete a buddy.
+ */
+
+ /// Call this function to:
+ /// 1. Change legacy network buddy params
+ /// 2. Add buddy on the legacy network with the given params
+ /// a. Accepting their friend request if present
+ /// b. Sending a friend request from ourselves.
/// \param user XMPP JID of user for which this event occurs. You can get it from NetworkPlugin::handleLoginRequest(). (eg. "user%gmail.com@xmpp.domain.tld")
/// \param buddyName Name of legacy network buddy. (eg. "user2@gmail.com")
/// \param alias Alias of legacy network buddy. If empty, then it's not changed on XMPP side.
@@ -89,7 +100,9 @@ class NetworkPlugin {
bool blocked = false
);
/// Call this method when buddy is removed from legacy network contact list.
/// \param user XMPP JID of user for which this event occurs. You can get it from NetworkPlugin::handleLoginRequest(). (eg. "user%gmail.com@xmpp.domain.tld")
/// \param buddyName Name of legacy network buddy. (eg. "user2@gmail.com")
void handleBuddyRemoved(const std::string &user, const std::string &buddyName);
@@ -89,7 +100,9 @@ class NetworkPlugin {
bool blocked = false
);
- /// Call this method when buddy is removed from legacy network contact list.
+ /// Call this method to:
+ /// 1. Removed the buddy from the legacy network contact list.
+ /// 2. Reject a friend request from this buddy.
/// \param user XMPP JID of user for which this event occurs. You can get it from NetworkPlugin::handleLoginRequest(). (eg. "user%gmail.com@xmpp.domain.tld")
/// \param buddyName Name of legacy network buddy. (eg. "user2@gmail.com")